<?php

/* --------------------------------------------------------------
   ContentRepository.php 2019-04-16
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class ContentRepository
 *
 * This class represents the content repository
 *
 * @category   System
 * @package    Content
 */
class ContentRepository implements ContentRepositoryInterface
{
    /**
     * Content writer
     *
     * @var ContentWriter
     */
    protected $writer;
    
    
    /**
     * ContentRepository constructor
     *
     * @param ContentWriterInterface $writer Content writer
     */
    public function __construct(ContentWriterInterface $writer)
    {
        $this->writer = $writer;
    }
    
    
    /**
     * Save the info page content
     *
     * @param InfoPageContent $infoPageContent Info page content
     *
     * @return ContentRepositoryInterface Same instance for chained method calls
     *
     * @throws LocalizedAttributeNotFoundException On missing locale-based value
     */
    public function storeInfoPageContent(InfoPageContent $infoPageContent)
    {
        $this->writer->storeInfoPageContent($infoPageContent);
        
        return $this;
    }
    
    
    /**
     * Save the link page content
     *
     * @param LinkPageContent $linkPageContent Link page content
     *
     * @return ContentRepositoryInterface Same instance for chained method calls
     *
     * @throws LocalizedAttributeNotFoundException On missing locale-based value
     */
    public function storeLinkPageContent(LinkPageContent $linkPageContent)
    {
        $this->writer->storeLinkPageContent($linkPageContent);
        
        return $this;
    }
    
    
    /**
     * Save the info element content
     *
     * @param InfoElementContent $infoElementContent Info element content
     *
     * @return ContentRepositoryInterface Same instance for chained method calls
     *
     * @throws LocalizedAttributeNotFoundException On missing locale-based value
     */
    public function storeInfoElementContent(InfoElementContent $infoElementContent)
    {
        $this->writer->storeInfoElementContent($infoElementContent);
        
        return $this;
    }
}