<?php
/* --------------------------------------------------------------
   MainThemeDirectories.inc.php 2018-11-13
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class MainThemeDirectories
 */
class MainThemeDirectories implements MainThemeDirectoriesInterface
{
    /**
     * @var \ThemeDirectory
     */
    protected $config;

    /**
     * @var \ThemeDirectory
     */
    protected $html;

    /**
     * @var \ThemeDirectory
     */
    protected $fonts;

    /**
     * @var \ThemeDirectory
     */
    protected $js;

    /**
     * @var \ThemeDirectory
     */
    protected $styles;

    /**
     * @var \ThemeDirectory
     */
    protected $styleEdit;

    /**
     * @var \ThemeDirectory
     */
    protected $images;


    /**
     * MainThemeDirectories constructor.
     *
     * @param \ThemeDirectoryRootInterface $root Path to root of theme.
     */
    public function __construct(ThemeDirectoryRootInterface $root)
    {
        $this->config = ThemeDirectory::create($root->withPath('config'));
        $this->html = ThemeDirectory::create($root->withPath('html' . DIRECTORY_SEPARATOR . 'system'));
        $this->fonts = ThemeDirectory::create($root->withPath('fonts'));
        $this->js = ThemeDirectory::create($root->withPath('javascripts' . DIRECTORY_SEPARATOR . 'system'));
        $this->styles = ThemeDirectory::create($root->withPath('styles' . DIRECTORY_SEPARATOR . 'system'));
        $this->styleEdit = ThemeDirectory::create($root->withPath('styles' . DIRECTORY_SEPARATOR . 'styleedit'));
        $this->images = ThemeDirectory::create($root->withPath('images'));
    }


    /**
     * Named constructor of MainThemeDirectories.
     *
     * @param \ThemeDirectoryRootInterface $root
     *
     * @return \MainThemeDirectories New instance.
     */
    public static function create(ThemeDirectoryRootInterface $root)
    {
        return MainFactory::create(static::class, $root);
    }


    /**
     * Returns the config theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getConfig()
    {
        return $this->config;
    }


    /**
     * Returns the html theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getHtml()
    {
        return $this->html;
    }


    /**
     * Returns the fonts theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getFonts()
    {
        return $this->fonts;
    }


    /**
     * Returns the js theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getJs()
    {
        return $this->js;
    }


    /**
     * Returns the styles theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getStyles()
    {
        return $this->styles;
    }


    /**
     * Returns the style edit theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getStyleEdit()
    {
        return $this->styleEdit;
    }


    /**
     * Returns the images theme directory.
     *
     * @return \ThemeDirectoryInterface
     */
    public function getImages()
    {
        return $this->images;
    }
}